@@ -19,14 +19,13 @@
 
 #include "querymatch.h"
 
-#include <QtWidgets/QAction>
+#include <QAction>
 #include <QIcon>
 #include <QReadWriteLock>
 #include <QSharedData>
 #include <QStringList>
 #include <QVariant>
 #include <QWeakPointer>
-#include <QDebug>
 
 #include "krunner_debug.h"
 
@@ -112,7 +111,7 @@ QueryMatch::~QueryMatch()
 
 bool QueryMatch::isValid() const
 {
-    return d->runner != 0;
+    return d->runner != nullptr;
 }
 
 QString QueryMatch::id() const
@@ -196,7 +195,7 @@ void QueryMatch::setId(const QString &id)
     }
 
     if (!id.isEmpty()) {
-        d->id.append('_').append(id);
+        d->id.append(QLatin1Char('_')).append(id);
     }
 
     d->idSetByData = false;
@@ -295,7 +294,7 @@ bool QueryMatch::operator<(const QueryMatch &other) const
             return other.isEnabled();
         }
 
-        if (d->relevance != other.d->relevance) {
+        if (!qFuzzyCompare(d->relevance, other.d->relevance)) {
             return d->relevance < other.d->relevance;
         }
 
